local pcall = pcall
local directions = {LEFT="Left", RIGHT="Right", TOP="Up", BOTTOM="Down"}
local mouseEvents = {OnRightClick="On Right-Click", OnMouseOver="On Mouse Over", Always="Always Shown"}

ZHunterModOptions = {
	type = "group",
	args = {
		autoshot = {
			type = "group",
			name = "Auto Shot Bar",
			desc = "Options to customize the Auto Shot Bar.",
			order = 1,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Auto Shot Bar.",
					get = function(info) return ZHunterMod_Saved["ZAutoShot"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZAutoShot"]["on"] = v end
				}
			}
		},
		aspect = {
			type = "group",
			name = "Aspect Bar",
			desc = "Options to customize the Aspect Bar.",
			order = 2,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Aspect Bar.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["on"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["on"] = v
						if ZAspect then
							if v then
								ZAspect:Show()
							else
								ZAspect:Hide()
							end
						end
					end
				},
				size = {
					type = "range",
					name = "Scale of Buttons",
					desc = "Scales the buttons in size.",
					min = 0.5,
					max = 2,
					step = 0.1,
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["size"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["size"] = v
						if ZAspect then
							ZAspect:UpdateSize(v)
						end
					end
				},
				count = {
					type = "range",
					name = "Number of Buttons",
					desc = "Set the number of buttons to show on the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["count"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["count"] = v
						if ZAspect then
							ZAspect:UpdateCount(v)
						end
					end
				},
				row = {
					type = "range",
					name = "Number of Rows",
					desc = "Set the number of rows on which to display the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["row"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["row"] = v
						if ZAspect then
							ZAspect:UpdateLayout(nil, nil, v)
						end
					end
				},
				event = {
					type = "select",
					name = "Expand Event",
					desc = "Set the event to make the bar expand.",
					values = mouseEvents,
					style = "dropdown",
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["event"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["event"] = v
						if ZAspect then
							ZAspect:UpdateAnchor(v)
						end
					end
				},
				direction = {
					type = "select",
					name = "Expand Direction",
					desc = "Set the direction that the bar will expand.",
					values = directions,
					style = "dropdown",
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["direction"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["direction"] = v
						if ZAspect then
							ZAspect:UpdateLayout(v)
						end
					end
				},
				stack = {
					type = "select",
					name = "Rows Stack",
					desc = "Set the way in which rows will stack on eachother.",
					values = directions,
					style = "dropdown",
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZAspect"]["stack"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZAspect"]["stack"] = v
						if ZAspect then
							ZAspect:UpdateLayout(nil, v)
						end
					end
				}
			}
		},
		track = {
			type = "group",
			name = "Track Bar",
			desc = "Options to customize the Track Bar.",
			order = 3,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Track Bar.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["on"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["on"] = v
						if ZTrack then
							if v then
								ZTrack:Show()
							else
								ZTrack:Hide()
							end
						end
					end
				},
				size = {
					type = "range",
					name = "Scale of Buttons",
					desc = "Scales the buttons in size.",
					min = 0.5,
					max = 2,
					step = 0.1,
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["size"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["size"] = v
						if ZTrack then
							ZTrack:UpdateSize(v)
						end
					end
				},
				count = {
					type = "range",
					name = "Number of Buttons",
					desc = "Set the number of buttons to show on the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["count"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["count"] = v
						if ZTrack then
							ZTrack:UpdateCount(v)
						end
					end
				},
				row = {
					type = "range",
					name = "Number of Rows",
					desc = "Set the number of rows on which to display the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["row"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["row"] = v
						if ZTrack then
							ZTrack:UpdateLayout(nil, nil, v)
						end
					end
				},
				event = {
					type = "select",
					name = "Expand Event",
					desc = "Set the event to make the bar expand.",
					values = mouseEvents,
					style = "dropdown",
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["event"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["event"] = v
						if ZTrack then
							ZTrack:UpdateAnchor(v)
						end
					end
				},
				direction = {
					type = "select",
					name = "Expand Direction",
					desc = "Set the direction that the bar will expand.",
					values = directions,
					style = "dropdown",
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["direction"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["direction"] = v
						if ZTrack then
							ZTrack:UpdateLayout(v)
						end
					end
				},
				stack = {
					type = "select",
					name = "Rows Stack",
					desc = "Set the way in which rows will stack on eachother.",
					values = directions,
					style = "dropdown",
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZTrack"]["stack"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrack"]["stack"] = v
						if ZTrack then
							ZTrack:UpdateLayout(nil, v)
						end
					end
				}
			}
		},
		trap = {
			type = "group",
			name = "Trap Bar",
			desc = "Options to customize the Trap Bar.",
			order = 4,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Trap Bar.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["on"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["on"] = v
						if ZTrap then
							if v then
								ZTrap:Show()
							else
								ZTrap:Hide()
							end
						end
					end
				},
				size = {
					type = "range",
					name = "Scale of Buttons",
					desc = "Scales the buttons in size.",
					min = 0.5,
					max = 2,
					step = 0.1,
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["size"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["size"] = v
						if ZTrap then
							ZTrap:UpdateSize(v)
						end
					end
				},
				count = {
					type = "range",
					name = "Number of Buttons",
					desc = "Set the number of buttons to show on the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["count"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["count"] = v
						if ZTrap then
							ZTrap:UpdateCount(v)
						end
					end
				},
				row = {
					type = "range",
					name = "Number of Rows",
					desc = "Set the number of rows on which to display the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["row"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["row"] = v
						if ZTrap then
							ZTrap:UpdateLayout(nil, nil, v)
						end
					end
				},
				event = {
					type = "select",
					name = "Expand Event",
					desc = "Set the event to make the bar expand.",
					values = mouseEvents,
					style = "dropdown",
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["event"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["event"] = v
						if ZTrap then
							ZTrap:UpdateAnchor(v)
						end
					end
				},
				direction = {
					type = "select",
					name = "Expand Direction",
					desc = "Set the direction that the bar will expand.",
					values = directions,
					style = "dropdown",
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["direction"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["direction"] = v
						if ZTrap then
							ZTrap:UpdateLayout(v)
						end
					end
				},
				stack = {
					type = "select",
					name = "Rows Stack",
					desc = "Set the way in which rows will stack on eachother.",
					values = directions,
					style = "dropdown",
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZTrap"]["stack"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZTrap"]["stack"] = v
						if ZTrap then
							ZTrap:UpdateLayout(nil, v)
						end
					end
				}
			}
		},
		pet = {
			type = "group",
			name = "Pet Bar",
			desc = "Options to customize the Pet Bar.",
			order = 5,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Pet Bar.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZPet"]["on"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["on"] = v
						if ZPet then
							if v then
								ZPet:Show()
							else
								ZPet:Hide()
							end
						end
					end
				},
				size = {
					type = "range",
					name = "Scale of Buttons",
					desc = "Scales the buttons in size.",
					min = 0.5,
					max = 2,
					step = 0.1,
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZPet"]["size"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["size"] = v
						if ZPet then
							ZPet:UpdateSize(v)
						end
					end
				},
				count = {
					type = "range",
					name = "Number of Buttons",
					desc = "Set the number of buttons to show on the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZPet"]["count"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["count"] = v
						if ZPet then
							ZPet:UpdateCount(v)
						end
					end
				},
				row = {
					type = "range",
					name = "Number of Rows",
					desc = "Set the number of rows on which to display the bar.",
					min = 1,
					max = 12,
					step = 1,
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZPet"]["row"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["row"] = v
						if ZPet then
							ZPet:UpdateLayout(nil, nil, v)
						end
					end
				},
				event = {
					type = "select",
					name = "Expand Event",
					desc = "Set the event to make the bar expand.",
					values = mouseEvents,
					style = "dropdown",
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZPet"]["event"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["event"] = v
						if ZPet then
							ZPet:UpdateAnchor(v)
						end
					end
				},
				direction = {
					type = "select",
					name = "Expand Direction",
					desc = "Set the direction that the bar will expand.",
					values = directions,
					style = "dropdown",
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZPet"]["direction"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["direction"] = v
						if ZPet then
							ZPet:UpdateLayout(v)
						end
					end
				},
				stack = {
					type = "select",
					name = "Rows Stack",
					desc = "Set the way in which rows will stack on eachother.",
					values = directions,
					style = "dropdown",
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZPet"]["stack"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZPet"]["stack"] = v
						if ZPet then
							ZPet:UpdateLayout(nil, v)
						end
					end
				}
			}
		},
		misdirect = {
			type = "group",
			name = "Misdirect",
			desc = "Options to customize the Misdirect messages.",
			order = 6,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Misdirect messages.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["on"] = v end
				},
				format = {
					type = "input",
					name = "Message Format",
					desc = "Set the format of how the message is broadcast. Use '$player' to represent the player's name when broadcast.",
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["format"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["format"] = v end
				},
				channel = {
					type = "range",
					name = "Custom Channel",
					desc = "Set the channel number through which to broadcast the message. Set to 0 to turn off.",
					min = 0,
					max = 10,
					step = 1,
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["channel"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["channel"] = v end
				},
				raid = {
					type = "toggle",
					name = "Raid",
					desc = "Broadcast the message through raid chat.",
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["raid"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["raid"] = v end
				},
				party = {
					type = "toggle",
					name = "Party",
					desc = "Broadcast the message through party chat.",
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["party"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["party"] = v end
				},
				yell = {
					type = "toggle",
					name = "Yell",
					desc = "Broadcast the message through yelling.",
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["yell"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["yell"] = v end
				},
				guild = {
					type = "toggle",
					name = "Guild",
					desc = "Broadcast the message through guild chat.",
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZMisdirect"]["guild"] end,
					set = function(info, v) ZHunterMod_Saved["ZMisdirect"]["guild"] = v end
				}
			}
		},
		arcanedispel = {
			type = "group",
			name = "Arcane Dispel",
			desc = "Options to customize the Dispel message from Arcane Shot.",
			order = 7,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Dispel message.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["on"] = v end
				},
				toSelf = {
					type = "toggle",
					name = "Personal Message",
					desc = "Toggle to display personal messages when dispelling.",
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["toSelf"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["toSelf"] = v end
				},
				showFail = {
					type = "toggle",
					name = "Show Failures",
					desc = "Toggle to display a personal message when you fail to dispel the target.",
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["showFail"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["showFail"] = v end
				},
				format = {
					type = "input",
					name = "Message",
					desc = "Change the format of the broadcast message. Use '$spell' and '$player' to print which spell was dispelled and from which player.",
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["format"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["format"] = v end
				},
				party = {
					type = "toggle",
					name = "Party",
					desc = "Broadcast the message through Party chat. Use the Gray Check if you only want to broadcast when the spell is one from your desired spells list.",
					tristate = true,
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["party"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["party"] = v end
				},
				raid = {
					type = "toggle",
					name = "Raid",
					desc = "Broadcast the message through Raid chat. Use the Gray Check if you only want to broadcast when the spell is one from your desired spells list.",
					tristate = true,
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["raid"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["raid"] = v end
				},
				raid_warning = {
					type = "toggle",
					name = "Raid Warning",
					desc = "Broadcast the message through Raid Warning. Use the Gray Check if you only want to broadcast when the spell is one from your desired spells list.",
					tristate = true,
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["raid_warning"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["raid_warning"] = v end
				},
				channel = {
					type = "toggle",
					name = "Custom Channel",
					desc = "Broadcast the message through a custom Channel. Use the Gray Check if you only want to broadcast when the spell is one from your desired spells list.",
					tristate = true,
					order = 8,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["channel"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["channel"] = v end
				},
				channelNum = {
					type = "range",
					name = "Channel Number",
					desc = "The number of the custom channel through which to broadcast.",
					min = 1,
					max = 10,
					step = 1,
					order = 9,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["channelNum"] end,
					set = function(info, v) ZHunterMod_Saved["ZArcaneDispel"]["channelNum"] = v end
				},
				desiredSpells = {
					type = "input",
					name = "Spells To Show",
					desc = "List the spells that you want to broadcast when they are dispelled (case sensitive).",
					multiline = true,
					order = 10,
					get = function(info) return ZHunterMod_Saved["ZArcaneDispel"]["desiredSpells"] end,
					set = function(info, v)
						ZHunterMod_Saved["ZArcaneDispel"]["desiredSpells"] = v
						ZArcaneDispelParse(v)
					end
				}
			}
		},
		freezefail = {
			type = "group",
			name = "Freeze Fail",
			desc = "Options to customize the message when Freezing Trap fails.",
			order = 7,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Dispel message.",
					order = 1,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["on"] = v end
				},
				toSelf = {
					type = "toggle",
					name = "Personal Message",
					desc = "Toggle to display personal messages when your trap fails.",
					order = 2,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["toSelf"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["toSelf"] = v end
				},
				playSound = {
					type = "toggle",
					name = "Play Sound",
					desc = "Toggle the playing of a sound when your trap fails.",
					order = 3,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["playSound"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["playSound"] = v end
				},
				format = {
					type = "input",
					name = "Message",
					desc = "Change the format of the broadcast message. Use '$player' and '$type' to print the target of the trap and type of failure (resist/immune).",
					order = 4,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["format"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["format"] = v end
				},
				party = {
					type = "toggle",
					name = "Party",
					desc = "Broadcast the message through Party chat. Use the Gray Check if you only want to broadcast when you are in the Arena.",
					tristate = true,
					order = 5,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["party"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["party"] = v end
				},
				raid = {
					type = "toggle",
					name = "Raid",
					desc = "Broadcast the message through Raid chat. Use the Gray Check if you only want to broadcast when you are in the Arena.",
					tristate = true,
					order = 6,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["raid"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["raid"] = v end
				},
				raid_warning = {
					type = "toggle",
					name = "Raid Warning",
					desc = "Broadcast the message through Raid Warning. Use the Gray Check if you only want to broadcast when you are in the Arena.",
					tristate = true,
					order = 7,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["raid_warning"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["raid_warning"] = v end
				},
				channel = {
					type = "toggle",
					name = "Custom Channel",
					desc = "Broadcast the message through a custom Channel. Use the Gray Check if you only want to broadcast when you are in the Arena.",
					tristate = true,
					order = 8,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["channel"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["channel"] = v end
				},
				channelNum = {
					type = "range",
					name = "Channel Number",
					desc = "The number of the custom channel through which to broadcast.",
					min = 1,
					max = 10,
					step = 1,
					order = 9,
					get = function(info) return ZHunterMod_Saved["ZFreezeFail"]["channelNum"] end,
					set = function(info, v) ZHunterMod_Saved["ZFreezeFail"]["channelNum"] = v end
				}
			}
		},
		tranq = {
			type = "group",
			name = "Tranquilize",
			desc = "Options to customize the Tranquilizing Shot rotation.",
			order = 8,
			args = {
				use = {
					type = "toggle",
					name = "Toggle Use",
					desc = "Toggle the display of the Tranquilizing Shot messages.",
					get = function(info) return ZHunterMod_Saved["ZHunterTranq"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZHunterTranq"]["on"] = v end
				}
			}
		},
		other = {
			type = "group",
			name = "Other Features",
			desc = "Enable/disable various other features that are available.",
			order = 9,
			args = {
				autostrip = {
					type = "toggle",
					name = "Auto Strip Button",
					desc = "Toggle the display of the Auto Strip Button.",
					get = function(info) return ZHunterMod_Saved["ZAutoStrip"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZAutoStrip"]["on"] = v end
				},
				antidaze = {
					type = "toggle",
					name = "Anti Daze",
					desc = "Toggle the display of the Aspect Bar.",
					get = function(info) return ZHunterMod_Saved["ZAntiDaze"]["on"] end,
					set = function(info, v) ZHunterMod_Saved["ZAntiDaze"]["on"] = v end
				}
			}
		}
	}
}

LibStub("AceConfig-3.0"):RegisterOptionsTable("ZHunterMod", ZHunterModOptions)

-- /script LibStub("AceConfigDialog-3.0"):Open("ZHunterMod")