local spells = {
	ZHUNTER_ASPECT_HAWK,
	ZHUNTER_ASPECT_MONKEY,
	ZHUNTER_ASPECT_VIPER,
	ZHUNTER_ASPECT_CHEETAH,
	ZHUNTER_ASPECT_WILD,
	ZHUNTER_ASPECT_PACK,
	ZHUNTER_ASPECT_BEAST,
	ZHUNTER_TRUESHOT_AURA
}
local numSpells = table.getn(spells)

for i = 1, numSpells do
	ZHunterModOptions.args.aspect.args["button"..i] = {
		type = "select",
		name = "Button "..i,
		desc = "Select which spell to use.",
		values = spells,
		style = "dropdown",
		order = 7 + i,
		get = function(info)
			local id = tonumber(info[2]:match("(%d+)"))
			return ZHunterMod_Saved["ZAspect"]["order"][id]
		end,
		set = function(info, v)
			local id = tonumber(info[2]:match("(%d+)"))
			ZHunterMod_Saved["ZAspect"]["order"][id] = v
			if ZAspect then
				ZAspect:Update()
			end
		end
	}
end

local buffs = {}
local texture = "Interface\\Icons\\Spell_Nature_WispSplode"
local BOOKTYPE_SPELL = BOOKTYPE_SPELL
local pairs = pairs
local macrotext = "/cast %s\n/cast %s"
local firstWasLast = false

function ZAspect:CheckBuffs()
	if (self.macro) then
		if (buffs[2] and self.buttons[3]) then
			self.icon:SetTexture(self.buttons[3].icon:GetTexture())
			self.id = self.buttons[3].id
		elseif (self.buttons[2]) then
			self.icon:SetTexture(self.buttons[2].icon:GetTexture())
			self.id = self.buttons[2].id
		end
	end
end

function ZAspect:Initialize()
	ZHunterMod_Saved["ZAspect"]["spell"] = {}
	for i = 1, numSpells do
		ZHunterMod_Saved["ZAspect"]["spell"][i] = spells[ZHunterMod_Saved["ZAspect"]["order"][i]]
	end
	self.spells = ZHunterMod_Saved["ZAspect"]["spell"]
	self.anchorevent = ZHunterMod_Saved["ZAspect"]["event"]
	self.direction = ZHunterMod_Saved["ZAspect"]["direction"]
	self.size = ZHunterMod_Saved["ZAspect"]["size"]
	self.count = ZHunterMod_Saved["ZAspect"]["count"]
	self.stack = ZHunterMod_Saved["ZAspect"]["stack"]
	self.rows = ZHunterMod_Saved["ZAspect"]["row"]
	self.macro = ZHunterMod_Saved["ZAspect"]["special"]
end

function ZAspect:AfterSpellSet()
	if (self.macro) then
		if (self.numButtons >= 2) then
			self:SetAttribute("macrotext", macrotext:format(GetSpellName(self.buttons[2].id, BOOKTYPE_SPELL), GetSpellName(self.buttons[3].id, BOOKTYPE_SPELL)))
		end
	end
end

function ZAspect:OnLoad()
	-- Hide the button if disabled
	if (not ZHunterMod_Saved["ZAspect"]["on"]) then
		self:Hide()
	end
	-- Register custom events
	self:RegisterEvent("COMBAT_TEXT_UPDATE")
	self:RegisterEvent("PLAYER_DEAD")
	-- Find the names of all spells
	local list = {}
	local num = self.numButtons
	for i = 1, num do
		local id = self.buttons[i].id
		if (id) then
			list[GetSpellName(id, BOOKTYPE_SPELL)] = i
		end
	end
	-- Check to see which buffs are already active
	local i = 1
	while (UnitBuff("player", i)) do
		local num = list[UnitBuff("player", i)]
		if (num) then
			self.buttons[num].icon:SetTexture(texture)
			buffs[num] = 1
		end
		i = i + 1
	end
	self:CheckBuffs()
end

function ZAspect:OnEvent()
	if (event == "COMBAT_TEXT_UPDATE") then
		if (arg1 == "SPELL_AURA_START" or arg1 == "SPELL_AURA_END") then
			local num = self.numButtons
			local start = 1
			if (self.macro) then
				start = 2
			end
			for i = start, num do
				local id = self.buttons[i].id
				if (id) then
					if (GetSpellName(id, BOOKTYPE_SPELL) == arg2) then
						if (arg1 == "SPELL_AURA_START") then
							self.buttons[i].icon:SetTexture(texture)
							buffs[i] = 1
							if (i == 2) then
								local temp = self.buttons[3].id
								self.icon:SetTexture(GetSpellTexture(temp, BOOKTYPE_SPELL))
								self.id = temp
							elseif (i == 3) then
								local temp = self.buttons[2].id
								self.icon:SetTexture(GetSpellTexture(temp, BOOKTYPE_SPELL))
								self.id = temp
							end
						elseif (arg1 == "SPELL_AURA_END") then
							self.buttons[i].icon:SetTexture(GetSpellTexture(id, BOOKTYPE_SPELL))
							buffs[i] = nil
						end
						self:CheckBuffs()
						return
					end
				end
			end
		end
	elseif (event == "PLAYER_DEAD") then
		for i in pairs(buffs) do
			local id = self.buttons[i].id
			if (id) then
				self.buttons[i].icon:SetTexture(GetSpellTexture(id, BOOKTYPE_SPELL))
				buffs[i] = nil
			end
		end
		self:CheckBuffs()
	end
end