local spells = {
--	ZHUNTER_PET_MEND,
--	ZHUNTER_PET_CALL,
	ZHUNTER_PET_FEED,
	ZHUNTER_PET_EYES,
	ZHUNTER_PET_DISMISS,
	ZHUNTER_PET_LORE,
	ZHUNTER_PET_TRAINING,
	ZHUNTER_PET_TAMING,
	ZHUNTER_PET_FEAR,
	ZHUNTER_PET_REVIVE
}
local numSpells = table.getn(spells)
for i = 1, numSpells do
	ZHunterModOptions.args.pet.args["button"..i] = {
		type = "select",
		name = "Button "..i,
		desc = "Select which spell to use.",
		values = spells,
		style = "dropdown",
		order = 7 + i,
		get = function(info)
			local id = tonumber(info[2]:match("(%d+)"))
			return ZHunterMod_Saved["ZPet"]["order"][id]
		end,
		set = function(info, v)
			local id = tonumber(info[2]:match("(%d+)"))
			ZHunterMod_Saved["ZPet"]["order"][id] = v
			if ZPet then
				ZPet:Update()
			end
		end
	}
end

local BOOKTYPE_SPELL = BOOKTYPE_SPELL
local spellids = {}
local macrotext = "/cast [target=pet, dead] "..ZHUNTER_PET_REVIVE.."; [modifier:ctrl] "..ZHUNTER_PET_REVIVE.."; [nopet] "..ZHUNTER_PET_CALL.."; "..ZHUNTER_PET_MEND
local macrotext2 = "/cast %s"

function ZPet:CheckPet()
	if (InCombatLockdown()) then
		if (IsControlKeyDown() or UnitIsDeadOrGhost("pet")) then
			self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_REVIVE))
			self.id = spellids[ZHUNTER_PET_REVIVE]
		elseif (not UnitExists("pet")) then
			self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_CALL))
			self.id = spellids[ZHUNTER_PET_CALL]
		else
			self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_MEND))
			self.id = spellids[ZHUNTER_PET_MEND]
		end
	else
		if (ZHunterMod_Saved["ZPet"]["dead"]) then
			if (not self.id or GetSpellName(self.id, BOOKTYPE_SPELL) ~= ZHUNTER_PET_REVIVE) then
				self:SetAttribute("macrotext", macrotext2:format(ZHUNTER_PET_REVIVE))
				self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_REVIVE))
				self.id = spellids[ZHUNTER_PET_REVIVE]
			end
		elseif (not UnitExists("pet")) then
			if (not self.id or GetSpellName(self.id, BOOKTYPE_SPELL) ~= ZHUNTER_PET_CALL) then
				self:SetAttribute("macrotext", macrotext2:format(ZHUNTER_PET_CALL))
				self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_CALL))
				self.id = spellids[ZHUNTER_PET_CALL]
			end
		else
			if (not self.id or GetSpellName(self.id, BOOKTYPE_SPELL) ~= ZHUNTER_PET_MEND) then
				self:SetAttribute("macrotext", macrotext2:format(ZHUNTER_PET_MEND))
				self.icon:SetTexture(GetSpellTexture(ZHUNTER_PET_MEND))
				self.id = spellids[ZHUNTER_PET_MEND]
			end
		end
	end
end

function ZPet:Initialize()
	ZHunterMod_Saved["ZPet"]["spell"] = {}
	for i = 1, numSpells do
		ZHunterMod_Saved["ZPet"]["spell"][i] = spells[ZHunterMod_Saved["ZPet"]["order"][i]]
	end
	self.spells = ZHunterMod_Saved["ZPet"]["spell"]
	self.anchorevent = ZHunterMod_Saved["ZPet"]["event"]
	self.direction = ZHunterMod_Saved["ZPet"]["direction"]
	self.size = ZHunterMod_Saved["ZPet"]["size"]
	self.count = ZHunterMod_Saved["ZPet"]["count"]
	self.stack = ZHunterMod_Saved["ZPet"]["stack"]
	self.rows = ZHunterMod_Saved["ZPet"]["row"]
	self.macro = ZHunterMod_Saved["ZPet"]["special"]
end

function ZPet:AfterSpellSet()
	if (self.macro) then
		self:CheckPet()
	end
	spellids[ZHUNTER_PET_REVIVE] = self:GetSpellID(ZHUNTER_PET_REVIVE)
	spellids[ZHUNTER_PET_CALL] = self:GetSpellID(ZHUNTER_PET_CALL)
	spellids[ZHUNTER_PET_MEND] = self:GetSpellID(ZHUNTER_PET_MEND)
end

function ZPet:OnLoad()
	-- Hide the button if disabled
	if (not ZHunterMod_Saved["ZPet"]["on"]) then
		self:Hide()
	end
	-- Register custom events
	self:RegisterEvent("UNIT_HEALTH")
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED")
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("UNIT_PET")
	self:RegisterEvent("MODIFIER_STATE_CHANGED")
	-- Set special modifier attributes
	self:SetAttribute("ctrl-type1", "macro")
	self:SetAttribute("ctrl-macrotext*", macrotext)
end

function ZPet:OnEvent()
	if (event == "UNIT_HEALTH") then
		if (arg1 == "pet") then
			if (UnitHealth("pet") == 0) then
				ZHunterMod_Saved["ZPet"]["dead"] = true
				self:CheckPet()
			else
				ZHunterMod_Saved["ZPet"]["dead"] = false
				self:CheckPet()
			end
		end
	elseif (event == "UNIT_SPELLCAST_SUCCEEDED") then
		if (arg1 == "player") then
			if (arg2 == ZHUNTER_PET_REVIVE) then
				ZHunterMod_Saved["ZPet"]["dead"] = false
				self:CheckPet()
			end
		end
	elseif (event == "PLAYER_REGEN_DISABLED") then
		self:SetAttribute("macrotext", macrotext)
	elseif (event == "PLAYER_REGEN_ENABLED" or event == "UNIT_PET") then
		self:CheckPet()
	elseif (event == "MODIFIER_STATE_CHANGED") then
		if (InCombatLockdown()) then
			self:CheckPet()
		end
	end
end