local getn = table.getn
local BOOKTYPE_SPELL = BOOKTYPE_SPELL
local reverse = {TOP = "BOTTOM", BOTTOM = "TOP", LEFT = "RIGHT", RIGHT = "LEFT"}

-- Find a spell's SpellBook ID
local function GetSpellID(spell)
	local found = false
	local i = 1
	for i = 1, 250 do
		local name = GetSpellName(i, BOOKTYPE_SPELL)
		if spell == name then
			found = true
		elseif found then
			return i - 1
		end
	end
end

-- Create a minor button
local function CreateChild(parent, index)
	local child = CreateFrame("Button", parent:GetName()..index, nil, "ZSpellButtonTemplate")
	child:SetAttribute("showstates", ";")
	child:SetAttribute("type", "spell")
	child:RegisterForClicks("LeftButtonUp")
	parent.parent:SetAttribute("AddChild", child)
	parent.numButtons = index
	return child
end

-- Create and setup a button for each spell
function ZSpellButton_Major_Setup(self)
	-- Stop if in combat
	if (InCombatLockdown()) then return end
	-- Run custom setup, if provided
	if (self.Initialize) then
		self:Initialize()
	end
	-- Setup spell buttons list
	if (not self.buttons) then
		self.buttons = {}
		-- Include the main button in the list
		self.buttons[1] = self
	end
	-- Setup each button
	local num = getn(self.spells)
	local counter = 0
	if (self.macro) then
		counter = 1
		self:SetAttribute("type1", "macro")
	end
	if (self.dynamic) then
		counter = 1
	end
	for i = 1, num do
		local id = GetSpellID(self.spells[i])
		if (id) then
			counter = counter + 1
			if (not self.buttons[counter]) then
				self.buttons[counter] = CreateChild(self, counter)
			end
			self.buttons[counter].icon:SetTexture(GetSpellTexture(id, BOOKTYPE_SPELL))
			self.buttons[counter]:SetAttribute("spell", self.spells[i])
			self.buttons[counter].id = id
		end
		if (self.display and counter >= self.display) then
			break
		end
	end
	-- Hide main button if no spells were found
	if (counter == 0 or (self.macro or self.dynamic) and counter == 1) then
		self:Hide()
		self.numButtons = 0
	-- Otherwise, setup the button layout
	else
		if (self.AfterSpellSet) then
			self:AfterSpellSet()
		end
		self:Show()
		self:UpdateCount()
		self:UpdateLayout()
		self:UpdateSize()
		self:UpdateAnchor()
	end
end

-- Update the number of buttons the user wants to display at one time
function ZSpellButton_Major_UpdateCount(self, count)
	-- Check parameters
	self.count = count or self.count or 99
	count = self.count
	for i = 2, self.numButtons do
		-- Display the number of buttons requested
		if (i <= count) then
			self.buttons[i]:SetAttribute("showstates", "1")
			if (self.parent:GetAttribute("state") == "1") then
				self.buttons[i]:Show()
			end
		-- Hide the rest
		else
			self.buttons[i]:SetAttribute("showstates", ";")
			self.buttons[i]:Hide()
		end
	end
	-- Update the layout to match the number of buttons
	self:UpdateLayout()
end

-- Update the button positioning
function ZSpellButton_Major_UpdateLayout(self, direction, stack, rows)
	-- Check parameters
	self.direction = direction or self.direction or "RIGHT"
	direction = self.direction
	self.stack = stack or self.stack or "BOTTOM"
	stack = self.stack
	self.rows = rows or self.rows or 1
	rows = self.rows
	-- Setup anchor positions
	local position = reverse[direction]
	if (not position) then
		direction = "RIGHT"
		position = "LEFT"
	end
	local stack2 = reverse[stack]
	if (not stack2) then
		stack = "RIGHT"
		stack2 = "LEFT"
	end
	-- Find the number of buttons displayed
	local count = self.count > self.numButtons and self.numButtons or self.count
	local counter = 1
	-- Find the number of columns to create
	local cols = ceil(count / rows)
	for i = 2, count do
		self.buttons[i]:ClearAllPoints()
		-- Start a new row after the column count has been reached
		if (counter >= cols) then
			self.buttons[i]:SetPoint(stack2, self.buttons[i - counter], stack, 0, 0)
			counter = 1
		-- Otherwise, position button next to the previous
		else
			self.buttons[i]:SetPoint(position, self.buttons[i - 1], direction, 0, 0)
			counter = counter + 1
		end
	end
end

-- Update the button's anchor event
function ZSpellButton_Major_UpdateAnchor(self, event)
	-- Check parameters
	self.anchorevent = event or self.anchorevent or "OnRightClick"
	event = self.anchorevent
	-- Set the state after a button is clicked
	for i = 1, self.numButtons do
		-- Remove the change if buttons are always visible
		if (event == "Always") then
			self.buttons[i]:SetAttribute("newstate1", ";")
		-- Otherwise, change the state to "0" (invisible) after clicked
		else
			self.buttons[i]:SetAttribute("newstate1", "0")
		end
	end
	-- Set the parent button's anchor event
	self:SetAttribute("*childstate-OnEnter", ";")
	self:SetAttribute("*childstate-OnLeave", ";")
	self:SetAttribute("newstate2", ";")
	if (event == "OnMouseOver") then
		self:SetAttribute("*childstate-OnEnter", "enter")
		self:SetAttribute("*childstate-OnLeave", "leave")
	elseif (event == "OnRightClick") then
		self:SetAttribute("newstate2", "0:1;1:0")
	elseif (event == "Always") then
		self.parent:SetAttribute("state", "1")
	end
end

-- Update the number of buttons the user wants to display at one time
function ZSpellButton_Major_UpdateSize(self, size)
	-- Check parameters
	self.size = size or self.size or 1
	size = self.size
	self.parent:SetScale(size)
end

-- Setup each button's frame objects
function ZSpellButton_Minor_OnLoad(self)
	self.icon = getglobal(self:GetName().."Icon")
	self.cooldown = getglobal(self:GetName().."Cooldown")
end

-- Setup the main button's frame objects
function ZSpellButton_Major_OnLoad(self)
	-- Initial button count
	self.numButtons = 0
	-- Setup as a minor button
	ZSpellButton_Minor_OnLoad(self)
	-- Setup parent frame
	self.parent = CreateFrame("Frame", nil, UIParent, "SecureStateHeaderTemplate")
	self:SetAttribute("anchorchild", self.parent)
	self.parent:ClearAllPoints()
	self.parent:SetPoint("CENTER", self, "CENTER", 0, 0)
	self:SetAttribute("*childraise-OnEnter", true)
	self.parent:SetAttribute("statemap-anchor-enter", "0:1")
	self.parent:SetAttribute("statemap-anchor-leave", ";")
	self.parent:SetAttribute("delaystatemap-anchor-leave", "1:0")
	self.parent:SetAttribute("delaytimemap-anchor-leave", "1:0.3")
	self.parent:SetAttribute("delayhovermap-anchor-leave", "1:true")
	-- Include frame functions
	self.GetSpellID = function(self, spell) return GetSpellID(spell) end
	self.UpdateCount = ZSpellButton_Major_UpdateCount
	self.UpdateLayout = ZSpellButton_Major_UpdateLayout
	self.UpdateAnchor = ZSpellButton_Major_UpdateAnchor
	self.UpdateSize = ZSpellButton_Major_UpdateSize
	self.Update = ZSpellButton_Major_Setup
	-- Setup major button
	self:HookScript("OnEnter", function(self)
		ZSpellButton_Minor_OnEnter(self)
		if (self.id) then
			GameTooltip:AddLine("Hold ALT to drag this button.", 0, 1, 1)
			GameTooltip:Show()
		end
	end)
	self:HookScript("OnLeave", ZSpellButton_Minor_OnLeave)
	self:RegisterForDrag("LeftButton")
	self:RegisterEvent("SPELL_UPDATE_COOLDOWN")
	self:RegisterEvent("PLAYER_LOGIN")
	self:SetAttribute("newstate1", ";")
	self:SetAttribute("type1", "spell")
	self:RegisterForClicks("LeftButtonUp", "RightButtonUp")
	self.parent:SetAttribute("AddChild", self)
end

-- OnEvent to update cooldown frames
function ZSpellButton_Major_OnEvent(self)
	if (event == "SPELL_UPDATE_COOLDOWN") then
		for i = 1, self.numButtons do
			local id = self.buttons[i].id
			if (id) then
				local start, duration = GetSpellCooldown(id, BOOKTYPE_SPELL)
				if (start > 0 and duration > 0) then
					self.buttons[i].cooldown:SetCooldown(start, duration)
				end
			end
		end
	elseif (event == "PLAYER_LOGIN") then
		ZSpellButton_Major_Setup(self)
		if (self.OnLoad) then
			self:OnLoad()
		end
		self:UnregisterEvent("PLAYER_LOGIN")
	end
	if (self.OnEvent) then
		self:OnEvent()
	end
end

-- Display a tooltip OnEnter
function ZSpellButton_Minor_OnEnter(self)
	if (self.id) then
		if (GetCVar("UberTooltips") == "1") then
			GameTooltip_SetDefaultAnchor(GameTooltip, self)
			GameTooltip:SetSpell(self.id, BOOKTYPE_SPELL)
		else
			GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
			GameTooltip:SetText(GetSpellName(self.id, BOOKTYPE_SPELL))
		end
	end
end

-- Hide the tooltip OnLeave
function ZSpellButton_Minor_OnLeave(self)
	GameTooltip:Hide()
end